==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/EntityAnalyticsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.EntityProviders
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings with single toggle.
 * Azure REST API version: 2023-06-01-preview. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * ## Example Usage
 * ### Update EyesOn settings.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var entityAnalytics = new AzureNative.SecurityInsights.EntityAnalytics("entityAnalytics", new()
 *     {
 *         ResourceGroupName = "myRg",
 *         SettingsName = "EyesOn",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewEntityAnalytics(ctx, "entityAnalytics", &securityinsights.EntityAnalyticsArgs{
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			SettingsName:      pulumi.String("EyesOn"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.EntityAnalytics;
 * import com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var entityAnalytics = new EntityAnalytics("entityAnalytics", EntityAnalyticsArgs.builder()
 *             .resourceGroupName("myRg")
 *             .settingsName("EyesOn")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:EntityAnalytics EyesOn /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/settings/{settingsName}
 * ```
 * @property entityProviders The relevant entity providers that are synced
 * @property kind The kind of the setting
 * Expected value is 'EntityAnalytics'.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property settingsName The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
 * @property workspaceName The name of the workspace.
 */
public data class EntityAnalyticsArgs(
    public val entityProviders: Output<List<Either<String, EntityProviders>>>? = null,
    public val kind: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val settingsName: Output<String>? = null,
    public val workspaceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs =
        com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs.builder()
            .entityProviders(
                entityProviders?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .kind(kind?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .settingsName(settingsName?.applyValue({ args0 -> args0 }))
            .workspaceName(workspaceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EntityAnalyticsArgs].
 */
@PulumiTagMarker
public class EntityAnalyticsArgsBuilder internal constructor() {
    private var entityProviders: Output<List<Either<String, EntityProviders>>>? = null

    private var kind: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var settingsName: Output<String>? = null

    private var workspaceName: Output<String>? = null

    /**
     * @param value The relevant entity providers that are synced
     */
    @JvmName("hqqrfjnbeeenpjts")
    public suspend fun entityProviders(`value`: Output<List<Either<String, EntityProviders>>>) {
        this.entityProviders = value
    }

    @JvmName("yfohuhdgoodikhup")
    public suspend fun entityProviders(vararg values: Output<Either<String, EntityProviders>>) {
        this.entityProviders = Output.all(values.asList())
    }

    /**
     * @param values The relevant entity providers that are synced
     */
    @JvmName("wuceylqjbfymblkv")
    public suspend fun entityProviders(values: List<Output<Either<String, EntityProviders>>>) {
        this.entityProviders = Output.all(values)
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'EntityAnalytics'.
     */
    @JvmName("slnqqeqqtxpdiivf")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("oewskkpmqqntugwu")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("lyaugrkghaukxspb")
    public suspend fun settingsName(`value`: Output<String>) {
        this.settingsName = value
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("pgbmltcxfcyoxkno")
    public suspend fun workspaceName(`value`: Output<String>) {
        this.workspaceName = value
    }

    /**
     * @param value The relevant entity providers that are synced
     */
    @JvmName("yrwrgecmqutvvqyb")
    public suspend fun entityProviders(`value`: List<Either<String, EntityProviders>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entityProviders = mapped
    }

    /**
     * @param values The relevant entity providers that are synced
     */
    @JvmName("gneliuekdgumfwkk")
    public suspend fun entityProviders(vararg values: Either<String, EntityProviders>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.entityProviders = mapped
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'EntityAnalytics'.
     */
    @JvmName("hxhepvbjevmyuoui")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("wxbnthxguonritmg")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("jykvyxiahwwodtox")
    public suspend fun settingsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingsName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("xhfbfrcidwxmkudg")
    public suspend fun workspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceName = mapped
    }

    internal fun build(): EntityAnalyticsArgs = EntityAnalyticsArgs(
        entityProviders = entityProviders,
        kind = kind,
        resourceGroupName = resourceGroupName,
        settingsName = settingsName,
        workspaceName = workspaceName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/EntityAnalyticsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.EntityProviders
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings with single toggle.
 * Azure REST API version: 2023-06-01-preview. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * ## Example Usage
 * ### Update EyesOn settings.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var entityAnalytics = new AzureNative.SecurityInsights.EntityAnalytics("entityAnalytics", new()
 *     {
 *         ResourceGroupName = "myRg",
 *         SettingsName = "EyesOn",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewEntityAnalytics(ctx, "entityAnalytics", &securityinsights.EntityAnalyticsArgs{
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			SettingsName:      pulumi.String("EyesOn"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.EntityAnalytics;
 * import com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var entityAnalytics = new EntityAnalytics("entityAnalytics", EntityAnalyticsArgs.builder()
 *             .resourceGroupName("myRg")
 *             .settingsName("EyesOn")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:EntityAnalytics EyesOn /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/settings/{settingsName}
 * ```
 * @property entityProviders The relevant entity providers that are synced
 * @property kind The kind of the setting
 * Expected value is 'EntityAnalytics'.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property settingsName The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
 * @property workspaceName The name of the workspace.
 */
public data class EntityAnalyticsArgs(
    public val entityProviders: Output<List<Either<String, EntityProviders>>>? = null,
    public val kind: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val settingsName: Output<String>? = null,
    public val workspaceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs =
        com.pulumi.azurenative.securityinsights.EntityAnalyticsArgs.builder()
            .entityProviders(
                entityProviders?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .kind(kind?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .settingsName(settingsName?.applyValue({ args0 -> args0 }))
            .workspaceName(workspaceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EntityAnalyticsArgs].
 */
@PulumiTagMarker
public class EntityAnalyticsArgsBuilder internal constructor() {
    private var entityProviders: Output<List<Either<String, EntityProviders>>>? = null

    private var kind: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var settingsName: Output<String>? = null

    private var workspaceName: Output<String>? = null

    /**
     * @param value The relevant entity providers that are synced
     */
    @JvmName("elwbehexdviceebw")
    public suspend fun entityProviders(`value`: Output<List<Either<String, EntityProviders>>>) {
        this.entityProviders = value
    }

    @JvmName("uepyamatbwchcffj")
    public suspend fun entityProviders(vararg values: Output<Either<String, EntityProviders>>) {
        this.entityProviders = Output.all(values.asList())
    }

    /**
     * @param values The relevant entity providers that are synced
     */
    @JvmName("ghucyfaivmavukbk")
    public suspend fun entityProviders(values: List<Output<Either<String, EntityProviders>>>) {
        this.entityProviders = Output.all(values)
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'EntityAnalytics'.
     */
    @JvmName("rltrxbxnihjfgthh")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ajutevmhvebdjtyf")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("mjqbfjywmovnmiqt")
    public suspend fun settingsName(`value`: Output<String>) {
        this.settingsName = value
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("bdfwcppvsnmcfcgn")
    public suspend fun workspaceName(`value`: Output<String>) {
        this.workspaceName = value
    }

    /**
     * @param value The relevant entity providers that are synced
     */
    @JvmName("vikitjffdownnpqk")
    public suspend fun entityProviders(`value`: List<Either<String, EntityProviders>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entityProviders = mapped
    }

    /**
     * @param values The relevant entity providers that are synced
     */
    @JvmName("ppekijugchcbsdkj")
    public suspend fun entityProviders(vararg values: Either<String, EntityProviders>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.entityProviders = mapped
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'EntityAnalytics'.
     */
    @JvmName("gtvyxbjndgkcfbuh")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gsemfggwlssnxipa")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("sjemyehrlcvsotwm")
    public suspend fun settingsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingsName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("wrfimbdjiihpjpgm")
    public suspend fun workspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceName = mapped
    }

    internal fun build(): EntityAnalyticsArgs = EntityAnalyticsArgs(
        entityProviders = entityProviders,
        kind = kind,
        resourceGroupName = resourceGroupName,
        settingsName = settingsName,
        workspaceName = workspaceName,
    )
}
